pub enum QueryMsg {
Claims {
address: String,
},
Investment {},
Balance {
address: String,
},
TokenInfo {},
Allowance {
owner: String,
spender: String,
},
}Variants
Claims
Claims shows the number of tokens this address can access when they are done unbonding
Investment
Investment shows metadata on the staking info of the contract
Balance
Implements CW20. Returns the current balance of the given address, 0 if unset.
TokenInfo
Implements CW20. Returns metadata on the contract - name, decimals, supply, etc.
Allowance
Implements CW20 “allowance” extension. Returns how much spender can use from owner account, 0 if unset.